diff mbox

c1x --> c11

Message ID 368807A2-3BA5-462C-8C84-EDA508F7B7F2@comcast.net
State New
Headers show

Commit Message

Mike Stump Oct. 22, 2013, 4:37 p.m. UTC
This updates test cases to use the non-deprecated form of the option.  c1x --> c11

Tested on x86_64-apple-darwin12.

Committed revision 203927.
diff mbox

Patch

Index: c1x-align-1.c
===================================================================
--- c1x-align-1.c	(revision 203926)
+++ c1x-align-1.c	(working copy)
@@ -1,6 +1,6 @@ 
-/* Test C1X alignment support.  Test valid code.  */
+/* Test C11 alignment support.  Test valid code.  */
 /* { dg-do compile } */
-/* { dg-options "-std=c1x -pedantic-errors" } */
+/* { dg-options "-std=c11 -pedantic-errors" } */
 
 #include <stddef.h>
 
Index: c1x-align-2.c
===================================================================
--- c1x-align-2.c	(revision 203926)
+++ c1x-align-2.c	(working copy)
@@ -1,6 +1,6 @@ 
-/* Test C1X alignment support.  Test valid code using stdalign.h.  */
+/* Test C11 alignment support.  Test valid code using stdalign.h.  */
 /* { dg-do run } */
-/* { dg-options "-std=c1x -pedantic-errors" } */
+/* { dg-options "-std=c11 -pedantic-errors" } */
 
 #include <stdalign.h>
 #include <stddef.h>
Index: c1x-align-3.c
===================================================================
--- c1x-align-3.c	(revision 203926)
+++ c1x-align-3.c	(working copy)
@@ -1,6 +1,6 @@ 
-/* Test C1X alignment support.  Test invalid code.  */
+/* Test C11 alignment support.  Test invalid code.  */
 /* { dg-do compile } */
-/* { dg-options "-std=c1x -pedantic-errors" } */
+/* { dg-options "-std=c11 -pedantic-errors" } */
 
 int a = _Alignof (void (void)); /* { dg-error "function" } */
 struct s;
Index: c1x-align-4.c
===================================================================
--- c1x-align-4.c	(revision 203926)
+++ c1x-align-4.c	(working copy)
@@ -1,7 +1,7 @@ 
-/* Test C1X alignment support.  Test reducing alignment (assumes there
+/* Test C11 alignment support.  Test reducing alignment (assumes there
    are at least some alignment constraints).  */
 /* { dg-do compile } */
-/* { dg-options "-std=c1x -pedantic-errors" } */
+/* { dg-options "-std=c11 -pedantic-errors" } */
 /* { dg-skip-if "no alignment constraints" { "avr-*-*" } { "*" } { "" } } */
 
 #include <stddef.h>
Index: c1x-align-5.c
===================================================================
--- c1x-align-5.c	(revision 203926)
+++ c1x-align-5.c	(working copy)
@@ -1,6 +1,6 @@ 
-/* Test C1X alignment support.  Test invalid code.  */
+/* Test C11 alignment support.  Test invalid code.  */
 /* { dg-do compile } */
-/* { dg-options "-std=c1x -pedantic-errors" } */
+/* { dg-options "-std=c11 -pedantic-errors" } */
 
 void foo (int []);
 void bar1 (int [_Alignas (double) 10]); /* { dg-error "expected expression before" } */
Index: c1x-anon-struct-1.c
===================================================================
--- c1x-anon-struct-1.c	(revision 203926)
+++ c1x-anon-struct-1.c	(working copy)
@@ -1,6 +1,6 @@ 
-/* Test for anonymous structures and unions in C1X.  */
+/* Test for anonymous structures and unions in C11.  */
 /* { dg-do compile } */
-/* { dg-options "-std=c1x -pedantic-errors" } */
+/* { dg-options "-std=c11 -pedantic-errors" } */
 
 #include <stddef.h>
 
Index: c1x-anon-struct-2.c
===================================================================
--- c1x-anon-struct-2.c	(revision 203926)
+++ c1x-anon-struct-2.c	(working copy)
@@ -1,7 +1,7 @@ 
-/* Test for anonymous structures and unions in C1X.  Test for invalid
+/* Test for anonymous structures and unions in C11.  Test for invalid
    cases.  */
 /* { dg-do compile } */
-/* { dg-options "-std=c1x -pedantic-errors" } */
+/* { dg-options "-std=c11 -pedantic-errors" } */
 
 typedef struct s0
 {
Index: c1x-anon-struct-3.c
===================================================================
--- c1x-anon-struct-3.c	(revision 203926)
+++ c1x-anon-struct-3.c	(working copy)
@@ -1,7 +1,7 @@ 
-/* Test for anonymous structures and unions in C1X.  Test for invalid
+/* Test for anonymous structures and unions in C11.  Test for invalid
    cases: typedefs disallowed by N1549.  */
 /* { dg-do compile } */
-/* { dg-options "-std=c1x -pedantic-errors" } */
+/* { dg-options "-std=c11 -pedantic-errors" } */
 
 typedef struct
 {
Index: c1x-float-1.c
===================================================================
--- c1x-float-1.c	(revision 203926)
+++ c1x-float-1.c	(working copy)
@@ -1,9 +1,9 @@ 
-/* Test for <float.h> C1X macros.  */
+/* Test for <float.h> C11 macros.  */
 /* Origin: Joseph Myers <joseph@codesourcery.com> */
 /* { dg-do preprocess } */
-/* { dg-options "-std=c1x -pedantic-errors" } */
+/* { dg-options "-std=c11 -pedantic-errors" } */
 
-/* This test checks that the C1X macros are defined;
+/* This test checks that the C11 macros are defined;
    it does not check the correctness of their values.  */
 
 #include <float.h>
Index: c1x-noreturn-1.c
===================================================================
--- c1x-noreturn-1.c	(revision 203926)
+++ c1x-noreturn-1.c	(working copy)
@@ -1,6 +1,6 @@ 
-/* Test C1X _Noreturn.  Test valid code.  */
+/* Test C11 _Noreturn.  Test valid code.  */
 /* { dg-do compile } */
-/* { dg-options "-std=c1x -pedantic-errors" } */
+/* { dg-options "-std=c11 -pedantic-errors" } */
 
 _Noreturn void exit (int);
 
Index: c1x-noreturn-2.c
===================================================================
--- c1x-noreturn-2.c	(revision 203926)
+++ c1x-noreturn-2.c	(working copy)
@@ -1,6 +1,6 @@ 
-/* Test C1X _Noreturn.  Test valid code using stdnoreturn.h.  */
+/* Test C11 _Noreturn.  Test valid code using stdnoreturn.h.  */
 /* { dg-do run } */
-/* { dg-options "-std=c1x -pedantic-errors" } */
+/* { dg-options "-std=c11 -pedantic-errors" } */
 
 #include <stdnoreturn.h>
 
Index: c1x-noreturn-3.c
===================================================================
--- c1x-noreturn-3.c	(revision 203926)
+++ c1x-noreturn-3.c	(working copy)
@@ -1,6 +1,6 @@ 
-/* Test C1X _Noreturn.  Test _Noreturn on main, hosted.  */
+/* Test C11 _Noreturn.  Test _Noreturn on main, hosted.  */
 /* { dg-do compile } */
-/* { dg-options "-std=c1x -pedantic-errors -fhosted" } */
+/* { dg-options "-std=c11 -pedantic-errors -fhosted" } */
 
 _Noreturn void exit (int);
 
Index: c1x-noreturn-4.c
===================================================================
--- c1x-noreturn-4.c	(revision 203926)
+++ c1x-noreturn-4.c	(working copy)
@@ -1,6 +1,6 @@ 
-/* Test C1X _Noreturn.  Test _Noreturn on main, freestanding.  */
+/* Test C11 _Noreturn.  Test _Noreturn on main, freestanding.  */
 /* { dg-do compile } */
-/* { dg-options "-std=c1x -pedantic-errors -ffreestanding" } */
+/* { dg-options "-std=c11 -pedantic-errors -ffreestanding" } */
 
 _Noreturn void exit (int);
 
Index: c1x-noreturn-5.c
===================================================================
--- c1x-noreturn-5.c	(revision 203926)
+++ c1x-noreturn-5.c	(working copy)
@@ -1,6 +1,6 @@ 
-/* Test C1X _Noreturn.  Test invalid uses.  */
+/* Test C11 _Noreturn.  Test invalid uses.  */
 /* { dg-do compile } */
-/* { dg-options "-std=c1x -pedantic-errors" } */
+/* { dg-options "-std=c11 -pedantic-errors" } */
 
 _Noreturn struct s; /* { dg-error "empty declaration" } */
 
Index: c1x-pointer-float-1.c
===================================================================
--- c1x-pointer-float-1.c	(revision 203926)
+++ c1x-pointer-float-1.c	(working copy)
@@ -1,6 +1,6 @@ 
-/* Test C1X constraint against pointer / floating-point casts.  */
+/* Test C11 constraint against pointer / floating-point casts.  */
 /* { dg-do compile } */
-/* { dg-options "-std=c1x -pedantic-errors" } */
+/* { dg-options "-std=c11 -pedantic-errors" } */
 
 void *p;
 float f;
Index: c1x-static-assert-1.c
===================================================================
--- c1x-static-assert-1.c	(revision 203926)
+++ c1x-static-assert-1.c	(working copy)
@@ -1,6 +1,6 @@ 
-/* Test C1X static assertions.  Valid assertions.  */
+/* Test C11 static assertions.  Valid assertions.  */
 /* { dg-do compile } */
-/* { dg-options "-std=c1x -pedantic-errors" } */
+/* { dg-options "-std=c11 -pedantic-errors" } */
 
 _Static_assert (1, "foo");
 
Index: c1x-static-assert-2.c
===================================================================
--- c1x-static-assert-2.c	(revision 203926)
+++ c1x-static-assert-2.c	(working copy)
@@ -1,6 +1,6 @@ 
-/* Test C1X static assertions.  Failed assertions.  */
+/* Test C11 static assertions.  Failed assertions.  */
 /* { dg-do compile } */
-/* { dg-options "-std=c1x -pedantic-errors" } */
+/* { dg-options "-std=c11 -pedantic-errors" } */
 
 _Static_assert (0, "assert1"); /* { dg-error "static assertion failed: \"assert1\"" } */
 
Index: c1x-static-assert-3.c
===================================================================
--- c1x-static-assert-3.c	(revision 203926)
+++ c1x-static-assert-3.c	(working copy)
@@ -1,6 +1,6 @@ 
-/* Test C1X static assertions.  Invalid assertions.  */
+/* Test C11 static assertions.  Invalid assertions.  */
 /* { dg-do compile } */
-/* { dg-options "-std=c1x -pedantic-errors" } */
+/* { dg-options "-std=c11 -pedantic-errors" } */
 
 _Static_assert (__INT_MAX__ * 2, "overflow"); /* { dg-warning "integer overflow in expression" } */
 /* { dg-error "overflow in constant expression" "error" { target *-*-* } 5 } */
Index: c1x-static-assert-4.c
===================================================================
--- c1x-static-assert-4.c	(revision 203926)
+++ c1x-static-assert-4.c	(working copy)
@@ -1,6 +1,6 @@ 
-/* Test C1X static assertions.  More invalid assertions.  */
+/* Test C11 static assertions.  More invalid assertions.  */
 /* { dg-do compile } */
-/* { dg-options "-std=c1x -pedantic-errors" } */
+/* { dg-options "-std=c11 -pedantic-errors" } */
 
 /* Static assertions not valid in old-style parameter declarations
    because declarations there must have declarators.  */
Index: c1x-static-assert-5.c
===================================================================
--- c1x-static-assert-5.c	(revision 203926)
+++ c1x-static-assert-5.c	(working copy)
@@ -1,5 +1,5 @@ 
-/* Test C1X static assertions.  Non-constant-expression without -pedantic.  */
+/* Test C11 static assertions.  Non-constant-expression without -pedantic.  */
 /* { dg-do compile } */
-/* { dg-options "-std=c1x" } */
+/* { dg-options "-std=c11" } */
 
 _Static_assert ((int)(1.0 + 1.0), "non-constant-expression");
Index: c1x-static-assert-6.c
===================================================================
--- c1x-static-assert-6.c	(revision 203926)
+++ c1x-static-assert-6.c	(working copy)
@@ -1,5 +1,5 @@ 
-/* Test C1X static assertions.  Non-constant-expression with -pedantic.  */
+/* Test C11 static assertions.  Non-constant-expression with -pedantic.  */
 /* { dg-do compile } */
-/* { dg-options "-std=c1x -pedantic" } */
+/* { dg-options "-std=c11 -pedantic" } */
 
 _Static_assert ((int)(1.0 + 1.0), "non-constant-expression"); /* { dg-warning "not an integer constant expression" } */
Index: c1x-typedef-1.c
===================================================================
--- c1x-typedef-1.c	(revision 203926)
+++ c1x-typedef-1.c	(working copy)
@@ -1,8 +1,8 @@ 
-/* Test typedef redeclaration in C1X.  */
+/* Test typedef redeclaration in C11.  */
 /* { dg-do compile } */
-/* { dg-options "-std=c1x -pedantic-errors" } */
+/* { dg-options "-std=c11 -pedantic-errors" } */
 
-/* C1X permits typedefs to be redeclared to the same type, but not to
+/* C11 permits typedefs to be redeclared to the same type, but not to
    different-but-compatible types, and not when the type is variably
    modified.  */
 
Index: c1x-uni-string-2.c
===================================================================
--- c1x-uni-string-2.c	(revision 203926)
+++ c1x-uni-string-2.c	(working copy)
@@ -1,6 +1,6 @@ 
-/* Test Unicode strings in C1X.  Test constraint.  */
+/* Test Unicode strings in C11.  Test constraint.  */
 /* { dg-do compile } */
-/* { dg-options "-std=c1x -pedantic-errors" } */
+/* { dg-options "-std=c11 -pedantic-errors" } */
 
 const void *p1 = L"a" u8"b"; /* { dg-error "concatenation" } */
 const void *p2 = L"a" "b" u8"c"; /* { dg-error "concatenation" } */
Index: c90-float-1.c
===================================================================
--- c90-float-1.c	(revision 203926)
+++ c90-float-1.c	(working copy)
@@ -3,7 +3,7 @@ 
 /* { dg-do preprocess } */
 /* { dg-options "-std=iso9899:1990 -pedantic-errors" } */
 
-/* This test checks that the C90 macros (but not the C99 or C1X ones)
+/* This test checks that the C90 macros (but not the C99 or C11 ones)
    are defined; it does not check the correctness of their values.  */
 
 #include <float.h>
Index: c99-float-1.c
===================================================================
--- c99-float-1.c	(revision 203926)
+++ c99-float-1.c	(working copy)
@@ -3,7 +3,7 @@ 
 /* { dg-do preprocess } */
 /* { dg-options "-std=iso9899:1999 -pedantic-errors" } */
 
-/* This test checks that the C99 macros (but not the C1X ones) are defined;
+/* This test checks that the C99 macros (but not the C11 ones) are defined;
    it does not check the correctness of their values.  */
 
 #include <float.h>
Index: torture/builtin-complex-1.c
===================================================================
--- torture/builtin-complex-1.c	(revision 203926)
+++ torture/builtin-complex-1.c	(working copy)
@@ -1,6 +1,6 @@ 
 /* Test __builtin_complex semantics.  */
 /* { dg-do run } */
-/* { dg-options "-std=c1x -pedantic-errors" } */
+/* { dg-options "-std=c11 -pedantic-errors" } */
 /* { dg-add-options ieee } */
 
 extern void exit (int);
Index: c1x-uni-string-1.c
===================================================================
--- c1x-uni-string-1.c	(revision 203926)
+++ c1x-uni-string-1.c	(working copy)
@@ -1,10 +1,10 @@ 
 /* Test Unicode strings in C1X.  Test valid code.  */
 /* { dg-do run } */
-/* { dg-options "-std=c1x -pedantic-errors" } */
+/* { dg-options "-std=c11 -pedantic-errors" } */
 
 /* More thorough tests are in c-c++-common/raw-string-*.c; this test
    verifies the particular subset (Unicode but not raw strings) that
-   is in C1X.  */
+   is in C11.  */
 
 typedef __CHAR16_TYPE__ char16_t;
 typedef __CHAR32_TYPE__ char32_t;
@@ -1,10 +1,10 @@ 
-/* Test Unicode strings in C1X.  Test valid code.  */
+/* Test Unicode strings in C11.  Test valid code.  */
 /* { dg-do run } */